@@ -317,6 +317,11 @@ class MathTable:
             kern2 += glyph2_kern.topleft.getkern(height2)
         return min(kern1, kern2), shiftdn
 
+    def listvariants(self, glyphid: int, vert: bool = True) -> dict[int, int]:
+        if vert:
+            return self._variantsvert.listvariants(glyphid)
+        return self._variantshorz.listvariants(glyphid)
+
     def variant(self, glyphid: int, height: float, vert: bool = True) -> GlyphType:
         ''' Get a height variant for the glyph
 
@@ -415,11 +420,15 @@ class AssembledGlyph(SimpleGlyph):
             ymin = min([g.path.bbox.ymin for g in glyphs])
             ymax = max([g.path.bbox.ymax for g in glyphs])
         bbox = BBox(xmin, xmax, ymin, ymax)
+        self._xadvance = max([g.advance() for g in glyphs])
         super().__init__(index, [], bbox, font)
 
-    def advance(self, nextchr=None) -> float:
+    def advance(self, nextchr=None) -> int:
         ''' X-advance '''
-        return self.bbox.xmax
+        if self.vert:
+            return self._xadvance
+        else:
+            return self.bbox.xmax
 
     def svgpath(self, x0: float = 0, y0: float = 0,
                 scale_factor: float = 1) -> Optional[ET.Element]:
@@ -536,6 +545,15 @@ class MathVariants:
         self.font = font
         self.vert = vert
 
+    def listvariants(self, glyphid: int) -> dict[int, int]:
+        ''' List all size variants '''
+        covidx = self.coverage.covidx(glyphid)
+        if covidx is None:
+            return {}
+
+        construction = self.construction[covidx]
+        return construction.variants
+
     def getvariant(self, glyphid: int, size: float) -> GlyphType:
         ''' Get the proper size variant for the glyphid '''
         glf: GlyphType
@@ -581,6 +599,10 @@ class MathVariants:
         else:
             height = ymax-ymin
             if height > ymaxs[-1] - ymins[-1] and construction.assembly:
+                if self.vert:
+                    height = max(
+                        -2*(ymin+self.font.math.consts.axisHeight),
+                        2*(ymax-self.font.math.consts.axisHeight))
                 glf = construction.assembly.assemble(height, self.minoverlap)
             else:
                 glf = self.font.glyph_fromid(gids[-1])
